PrinterType

Enum PrinterType 

pub enum PrinterType {
Show 24 variants PT_9200DX, PT_2300, PT_2420PC, PT_2450PC, PT_1950, PT_2700, PT_1230PC, PT_2430PC, PT_1230PC_PLite, PT_2430PC_PLite, PT_2730, PT_H500, PT_E500, PT_P700, PT_P750W, PT_P700_PLite, PT_P750W_PLite, PT_D410, PT_D450, PT_D460BT, PT_D600, PT_D610BT, PT_P710BT, PT_E310BT,
}

Variants



PT_9200DX



PT_2300



PT_2420PC



PT_2450PC



PT_1950



PT_2700



PT_1230PC

Notes about the PT-1230PC: While it is true that this printer supports max 12mm tapes, it apparently expects > 76px data - the first 32px must be blank.



PT_2430PC



PT_1230PC_PLite



PT_2430PC_PLite



PT_2730

Notes about the PT-2730: was reported to need 48px whitespace within png-images before content is actually printed - can not check this



PT_H500

Note about the PT-E500: was reported by Jesse Becker with the remark that it also needs some padding (white pixels)



PT_E500

Note about the PT-E500: was reported by Jesse Becker with the remark that it also needs some padding (white pixels)



PT_P700



PT_P750W



PT_P700_PLite



PT_P750W_PLite



PT_D410



PT_D450

Notes about the PT-D450: I’m unsure if print width really is 128px



PT_D460BT



PT_D600

PT-D600 was reported to work, but with some quirks (premature cutting of tape, printing maximum of 73mm length)



PT_D610BT



PT_P710BT



PT_E310BT

added by Christian, PT-E310BT (aka PT-E310BTVP) requires these flags, otherwise not returning from libusb_bulk_transfer-call printhead 128px, 180 dpi resolution 3,5/6/9/12/18 mm TZe Tapes, 12mm and 18mm tested 5,2/9/11,2 mm HSe heat shrink tubes not tested, probably requiring extension of struct _pt_tape_info

Implementations

Source

impl PrinterType

pub fn from_usb(vendor: u16, product: u16) -> Option<Self>

pub fn iter() -> impl Iterator<Item = Self>

pub fn iter_info() -> impl Iterator<Item = (&'static Self, &'static PrinterInfo)>

pub fn info(&self) -> PrinterInfo